@@ -12,11 +12,17 @@
 #' editLattice.
 #' @param Z A vector of response variable values.
 #' @param locations A two-column matrix or data frame of data locations.
+#' \itemize{
+#' \item init_quantvar Vector of initial quantitative variables
+#' \item init_prob Vector of initial probability density
+#' \item which_nodes What nodes are closest to each data location
+#' }
 #' 
 #' #' @references Ronald P. Barry, Julie McIntyre.  Estimating animal densities and home
 #' range in regions with irregular boundaries and holes:  A lattice-based
 #' alternative to the kernel density estimator.
-#' Ecological Modelling 222 (2011)  1666-1672.
+#' Ecological Modelling 222 (2011)  1666-1672.  
+#' <doi:10.1080/10618600.2017.1375935>
 #' 
 #' @references Julie McIntyre, Ronald P. Barry (2018)  A Lattice-Based 
 #' Smoother for Regions with Irregular Boundaries and Holes.  
@@ -25,7 +31,7 @@
 #' @import utils
 #' @import graphics
 #' @import stats
-#' @import spatstat
+#' @import spatstat.geom
 #' @import sp
 #' @export
 addQuantVar <-
@@ -48,9 +54,9 @@ function(formLatticeOutput, Z, locations){
 #
   temp <- sp::bbox(rbind(locations,nodes))
   bound_vect <- c(temp[1,1], temp[1,2], temp[2,1], temp[2,2])
-  X <- spatstat::as.ppp(locations, W=bound_vect)
-  Y <- spatstat::as.ppp(nodes, W=bound_vect)
-  closest <- spatstat::nncross(X,Y)$which
+  X <- spatstat.geom::as.ppp(locations, W=bound_vect)
+  Y <- spatstat.geom::as.ppp(nodes, W=bound_vect)
+  closest <- spatstat.geom::nncross(X,Y)$which
 #
 #  The output will be a vector that gives an initial prob
 #  at each node, depending on number of corresponding
